@@ -45,7 +45,7 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-VERSION = (2, 7, 3, 4)
+VERSION = (2, 7, 3, 5)
 __version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
@@ -326,3 +326,7 @@ def forking_enable(value):
         if value and not hasattr(os, 'fork'):
             raise ValueError('os.fork() not found')
         forking._forking_is_enabled = bool(value)
+        if not value:
+            os.environ["MULTIPROCESSING_FORKING_DISABLE"] = "1"
+if os.environ.get("MULTIPROCESSING_FORKING_DISABLE"):
+    forking_enable(False)
